<script setup>
import AuthenticatedLayout from '@/Layouts/AuthenticatedLayout.vue';
import ProductFilter from '@/components/ProductFilter.vue'

import { ref, onMounted, computed, reactive } from 'vue';
import { Head, usePage, useForm } from '@inertiajs/vue3';

const page = usePage();
const orders = computed(() => page.props.orders.data || []);
console.log(orders);
const isMobile = ref(window.innerWidth <= 768);
const flashMessage = ref('');

const handleResize = () => {
    isMobile.value = window.innerWidth <= 768; // Adjust the threshold as needed
}

onMounted(() => {
    window.addEventListener('resize', handleResize);
    handleResize();
});

const orderDetails = (item_number) => {
    // window.location.href = `/product/${item_number}`;
    console.log("Get Order Details");
};
</script>

<template>
    <Head title="My Account" />

    <AuthenticatedLayout>
        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">My Account</h2>
        </template>

        <div class="py-12 container">
            <div class="row">
                <div v-if="flashMessage" class="col-12 max-w-7xl mx-auto sm:px-6 lg:px-8 font-bold text-red-600">
                    <div class="form-row mb-6">
                        <div class="col-md-6">
                            <h4>{{ flashMessage }}</h4>
                        </div>
                    </div>
                </div>

                <div class="col-12 col-sm-3 max-w-7xl mx-auto sm:px-6 lg:px-8">
                    <div class="bg-white overflow-hidden shadow-sm sm:rounded-lg">
                        <ProductFilter></ProductFilter>
                    </div>
                </div>
                <div class="col-12 col-sm-9 max-w-7xl mx-auto sm:px-6 lg:px-8">
                    <div v-if="loading">Loading...</div>
                    <table v-else-if="orders && orders.length" class="table table-striped">
                        <thead>
                            <tr>
                                <th>Order ID</th>
                                <th>Price</th>
                                <th>Date</th>
                                <th></th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr v-for="order in orders" :key="order.id">
                                <td><a href="#">{{ order.id }}</a></td>
                                <td>{{ order.total_price }}</td>
                                <td>{{ order.created_at }}</td>
                                <td></td>
                            </tr>
                        </tbody>
                    </table>
                    <p v-else>No products found.</p>
                </div>
            </div>
        </div>
    </AuthenticatedLayout>
</template>
<style scoped>
table tr td {
    max-width: 200px;
}
.cart_qty input {
    width: 70px;
    padding: 0 5px;
    height: 33px;
}
</style>
